==> robotframework-xlibrary-11.0.2.tar.gz: robotframework-xlibrary-11.0.2/src/XLibrary/submodule2/module1.py <==
# submodule2/module1.py
# -*- coding: utf-8 -*-
import logging
from robot.api.deco import keyword

class Module21:
    def __init__(self):
        logging.basicConfig(level=logging.INFO, format='%(message)s')

    def PrintTEST21(self):
        """ พิมพ์ข้อความ 'Hello, world!' ลงในคอนโซล แบบไม่ได้แอดคีย์ """
        print("Hello, world! เทสภาษาไทย111")

    def log_tree_structure(self, data, level=0, prefix=''):
        indent = "│   " * level
        branch = "├── " if level > 0 else ""
        if isinstance(data, dict):
            for key, value in data.items():
                if isinstance(value, (dict, list)):
                    logging.info(f"{indent}{branch}{key}")
                    self.log_tree_structure(value, level + 1)
                else:
                    logging.info(f"{indent}{branch}{key}: {value}")
        elif isinstance(data, list):
            for i, item in enumerate(data):
                logging.info(f"{indent}├── [{i}]")
                self.log_tree_structure(item, level + 1)
        else:
            logging.info(f"{indent}{branch}{prefix}{data}")

    @keyword("Log Tree Data")
    def log_tree_data(self, data):
        """ 
        ***|    Description     |***
        |   *`Log Tree Data`*   |   เป็น Keyword สำหรับ Log Data ให้ออกมาเป็น Tree Data |


        ***|    Example     |***
        | *`Log Tree Data`* | *`${value}`* |
        

        ***|    Parameters     |***
            - **`data`**  ข้อมูล Json.


       *`Create By Tassana Khrueawan`*
        """
        self.log_tree_structure(data)

==> robotframework-xlibrary-12.0.0.tar.gz: robotframework-xlibrary-12.0.0/src/XLibrary/submodule2/module1.py <==
# submodule2/module1.py
# -*- coding: utf-8 -*-
import logging
from robot.api.deco import keyword
from robot.libraries.BuiltIn import BuiltIn
from robot.api import logger

class XLog:
    def __init__(self):
        # กำหนดค่าเริ่มต้นของการบันทึก Log
        logging.basicConfig(level=logging.INFO, format='%(message)s')
        self.builtin = BuiltIn()

    def log_tree_structure(self, data, level=0, prefix=''):
        """
        ฟังก์ชันช่วยสำหรับการแสดงโครงสร้างข้อมูลในรูปแบบต้นไม้ (Tree Structure)
        
        พารามิเตอร์:
        - data: ข้อมูลที่ต้องการแสดง
        - level: ระดับของการแสดงผล (ใช้สำหรับการจัดเรียง)
        - prefix: คำนำหน้าข้อมูล (ถ้ามี)
        """
        indent = "│   " * level
        branch = "├── " if level > 0 else ""
        if isinstance(data, dict):
            for key, value in data.items():
                if isinstance(value, (dict, list)):
                    logging.info(f"{indent}{branch}{key}")
                    self.log_tree_structure(value, level + 1)
                else:
                    logging.info(f"{indent}{branch}{key}: {value}")
        elif isinstance(data, list):
            for i, item in enumerate(data):
                logging.info(f"{indent}├── [{i}]")
                self.log_tree_structure(item, level + 1)
        else:
            logging.info(f"{indent}{branch}{prefix}{data}")

    @keyword("XLog Tree Data")
    def log_tree_data(self, data):
        """ 
        ***|    Description     |***
        |   *`XLog Tree Data`*   |   เป็น Keyword สำหรับ Log Data ให้ออกมาเป็น Tree Data |


        ***|    Example     |***
        | *`XLog Tree Data`* | *`${value}`* |
        

        ***|    Parameters     |***
        - **`data`**: ข้อมูล JSON.

        
        *`Create By Tassana Khrueawan`*
        """
        # เรียกใช้ฟังก์ชัน log_tree_structure เพื่อแสดงโครงสร้างข้อมูลในรูปแบบต้นไม้
        self.log_tree_structure(data)
